==> edge-login-ui-rn-0.9.23.tgz: package/lib/components/common/Header.js <==
import * as React from 'react';
import { Platform, View } from 'react-native';
import LinearGradient from 'react-native-linear-gradient';
import s from '../../common/locales/strings';
import T from '../../components/common/FormattedText';
import * as Colors from '../../constants/Colors';
import * as Constants from '../../constants/index';
import * as Styles from '../../styles/index';
import { scale } from '../../util/scaling';
import { Button } from '../common/Button';
import { HeaderBackButton } from '../common/HeaderBackButton';
/**
 * The raw Header for a scene.
 * This is exported because ChangeRecoveryConfirmScene isn't a real scene,
 * and pulls this in specially.
 */
export class Header extends React.Component {
    render() {
        return (React.createElement(LinearGradient, { style: [styles.container, { paddingTop: 0 }], start: { x: 0, y: 0 }, end: { x: 1, y: 0 }, colors: Colors.GRADIENT },
            React.createElement(View, { style: styles.left }, this.renderBack()),
            this.renderText(),
            React.createElement(View, { style: styles.right }, this.renderSkip())));
    }
    renderBack() {
        if (this.props.onBack == null)
            return null;
        return (React.createElement(HeaderBackButton, { onPress: this.props.onBack, styles: styles.headerBackButtonStyle, label: s.strings.back }));
    }
    renderText() {
        return (React.createElement(View, { style: styles.center },
            React.createElement(T, { style: styles.headlineText }, this.props.title)));
    }
    renderSkip() {
        if (this.props.onSkip == null)
            return null;
        return (React.createElement(Button, { onPress: this.props.onSkip, downStyle: styles.textButton.downStyle, downTextStyle: styles.textButton.downTextStyle, upStyle: styles.textButton.upStyle, upTextStyle: styles.textButton.upTextStyle, label: s.strings.skip }));
    }
}
const styles = {
    container: {
        position: 'relative',
        height: scale(Platform.OS === 'ios' ? 42 : 54),
        width: '100%',
        backgroundColor: Constants.TRANSPARENT,
        flexDirection: 'row',
        paddingTop: scale(6)
    },
    headerBackButtonStyle: {
        backButton: {
            flexDirection: 'row',
            alignItems: 'center'
        },
        backIconStyle: {
            position: 'relative',
            top: scale(1),
            paddingLeft: scale(10),
            paddingRight: scale(2),
            color: Constants.WHITE,
            fontSize: scale(22)
        },
        sideText: {
            color: Constants.WHITE,
            fontSize: scale(14)
        },
        icon: {
            color: Constants.WHITE
        },
        default: {
            backgroundColor: Constants.TRANSPARENT,
            color: Constants.WHITE
        }
    },
    left: {
        flex: 1,
        justifyContent: 'center'
    },
    center: {
        flex: 3,
        justifyContent: 'center'
    },
    right: {
        flex: 1,
        justifyContent: 'center'
    },
    headlineText: {
        fontSize: scale(17),
        width: '100%',
        textAlign: 'center',
        color: Constants.WHITE
    },
    subHeadText: {
        fontSize: scale(11),
        width: '100%',
        textAlign: 'center',
        color: Constants.ACCENT_MINT
    },
    textButton: {
        upStyle: Object.assign(Object.assign({}, Styles.TextOnlyButtonUpScaledStyle), { width: '100%' }),
        upTextStyle: Object.assign(Object.assign({}, Styles.TextOnlyButtonTextUpScaledStyle), { width: '100%', color: Constants.WHITE, fontSize: scale(Constants.FONTS.defaultButtonTextSize) }),
        downTextStyle: Object.assign(Object.assign({}, Styles.TextOnlyButtonTextDownScaledStyle), { width: '100%', color: Constants.SECONDARY, fontSize: scale(Constants.FONTS.defaultButtonTextSize) }),
        downStyle: Object.assign(Object.assign({}, Styles.TextOnlyButtonDownScaledStyle), { width: '100%', height: scale(50) })
    }
};

==> edge-login-ui-rn-0.10.11.tgz: package/lib/components/common/Header.js <==
import * as React from 'react';
import { Platform, View } from 'react-native';
import LinearGradient from 'react-native-linear-gradient';
import s from '../../common/locales/strings';
import T from '../../components/common/FormattedText';
import * as Colors from '../../constants/Colors';
import * as Constants from '../../constants/index';
import * as Styles from '../../styles/index';
import { scale } from '../../util/scaling';
import { HeaderBackButton } from '../common/HeaderBackButton';
import { MainButton } from '../themed/MainButton';
/**
 * The raw Header for a scene.
 * This is exported because ChangeRecoveryConfirmScene isn't a real scene,
 * and pulls this in specially.
 */
export class Header extends React.Component {
    render() {
        return (React.createElement(LinearGradient, { style: [styles.container, { paddingTop: 0 }], start: { x: 0, y: 0 }, end: { x: 1, y: 0 }, colors: Colors.GRADIENT },
            React.createElement(View, { style: styles.left }, this.renderBack()),
            this.renderText(),
            React.createElement(View, { style: styles.right }, this.renderSkip())));
    }
    renderBack() {
        if (this.props.onBack == null)
            return null;
        return (React.createElement(HeaderBackButton, { onPress: this.props.onBack, styles: styles.headerBackButtonStyle, label: s.strings.back }));
    }
    renderText() {
        return (React.createElement(View, { style: styles.center },
            React.createElement(T, { style: styles.headlineText }, this.props.title)));
    }
    renderSkip() {
        if (this.props.onSkip == null)
            return null;
        return (React.createElement(MainButton, { onPress: this.props.onSkip, label: s.strings.skip, type: "textOnly" }));
    }
}
const styles = {
    container: {
        position: 'relative',
        height: scale(Platform.OS === 'ios' ? 42 : 54),
        width: '100%',
        backgroundColor: Constants.TRANSPARENT,
        flexDirection: 'row',
        paddingTop: scale(6)
    },
    headerBackButtonStyle: {
        backButton: {
            flexDirection: 'row',
            alignItems: 'center'
        },
        backIconStyle: {
            position: 'relative',
            top: scale(1),
            paddingLeft: scale(10),
            paddingRight: scale(2),
            color: Constants.WHITE,
            fontSize: scale(22)
        },
        sideText: {
            color: Constants.WHITE,
            fontSize: scale(14)
        },
        icon: {
            color: Constants.WHITE
        },
        default: {
            backgroundColor: Constants.TRANSPARENT,
            color: Constants.WHITE
        }
    },
    left: {
        flex: 1,
        justifyContent: 'center'
    },
    center: {
        flex: 3,
        justifyContent: 'center'
    },
    right: {
        flex: 1,
        justifyContent: 'center'
    },
    headlineText: {
        fontSize: scale(17),
        width: '100%',
        textAlign: 'center',
        color: Constants.WHITE
    },
    subHeadText: {
        fontSize: scale(11),
        width: '100%',
        textAlign: 'center',
        color: Constants.ACCENT_MINT
    },
    textButton: {
        upStyle: Object.assign(Object.assign({}, Styles.TextOnlyButtonUpScaledStyle), { width: '100%' }),
        upTextStyle: Object.assign(Object.assign({}, Styles.TextOnlyButtonTextUpScaledStyle), { width: '100%', color: Constants.WHITE, fontSize: scale(Constants.FONTS.defaultButtonTextSize) }),
        downTextStyle: Object.assign(Object.assign({}, Styles.TextOnlyButtonTextDownScaledStyle), { width: '100%', color: Constants.SECONDARY, fontSize: scale(Constants.FONTS.defaultButtonTextSize) }),
        downStyle: Object.assign(Object.assign({}, Styles.TextOnlyButtonDownScaledStyle), { width: '100%', height: scale(50) })
    }
};
